==> nextcloud-14.0.1.tgz: nextcloud/apps/dav/l10n/is.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Dagatal",
    "Todos" : "Verkþættir",
    "Personal" : "Einka",
    "{actor} created calendar {calendar}" : "{actor} bjó til dagatalið {calendar}",
    "You created calendar {calendar}" : "Þú bjóst til dagatalið {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eyddi dagatalinu {calendar}",
    "You deleted calendar {calendar}" : "Þú eyddir dagatalinu {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppfærði dagatalið {calendar}",
    "You updated calendar {calendar}" : "Þú uppfærðir dagatalið {calendar}",
    "You shared calendar {calendar} as public link" : "Þú deildir dagatalinu {calendar} sem almenningstengli",
    "You removed public link for calendar {calendar}" : "Þú fjarlægðir almenningstengilinn fyrir dagatalið {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deildi dagatalinu {calendar} með þér",
    "You shared calendar {calendar} with {user}" : "Þú deildir dagatalinu {calendar} með {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deildi dagatalinu {calendar} með {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} tók af deilingu á dagatalinu {calendar} frá þér",
    "You unshared calendar {calendar} from {user}" : "Þú tókst af deilingu á dagatalinu {calendar} frá {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} tók af deilingu á dagatalinu {calendar} frá {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} tók af deilingu á dagatalinu {calendar} frá þeim sjálfum",
    "You shared calendar {calendar} with group {group}" : "Þú deildir dagatalinu {calendar} með hópnum {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deildi dagatalinu {calendar} með hópnum {group}",
    "You unshared calendar {calendar} from group {group}" : "Þú tókst af deilingu á dagatalinu {calendar} frá hópnum {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} tók af deilingu á dagatalinu {calendar} frá hópnum {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} bjó til atburðinn {event} í dagatalinu {calendar}",
    "You created event {event} in calendar {calendar}" : "Þú bjóst til atburðinn {event} í dagatalinu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eyddi atburðinum {event} úr dagatalinu {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Þú eyddir atburðinum {event} úr dagatalinu {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppfærði atburðinn {event} í dagatalinu {calendar}",
    "You updated event {event} in calendar {calendar}" : "Þú uppfærðir atburðinn {event} í dagatalinu {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} bjó til verkefnið {todo} á listanum {calendar}",
    "You created todo {todo} in list {calendar}" : "Þú bjóst til verkefnið {todo} á listanum {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eyddi verkefninu {todo} af listanum {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Þú eyddir verkefninu {todo} af listanum {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppfærði verkefnið {todo} á listanum {calendar}",
    "You updated todo {todo} in list {calendar}" : "Þú uppfærðir verkefnið {todo} á listanum {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} leysti verkefnið {todo} á listanum {calendar}",
    "You solved todo {todo} in list {calendar}" : "Þú leystir verkefnið {todo} á listanum {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} opnaði aftur verkefnið {todo} á listanum {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Þú opnaðir aftur verkefnið {todo} á listanum {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Dagatali</strong> var breytt",
    "A calendar <strong>event</strong> was modified" : "<strong>Atburði</strong> dagatals var breytt",
    "A calendar <strong>todo</strong> was modified" : "<strong>Verkefnalista</strong> dagatals var breytt",
    "Contact birthdays" : "Afmælisdagar tengiliðar",
    "%s via %s" : "%s með %s",
    "Invitation canceled" : "Hætt við boð",
    "Hello %s," : "Halló %s,",
    "The meeting »%s« with %s was canceled." : "Hætt var við fundinn »%s« með %s.",
    "Invitation updated" : "Boð uppfært",
    "The meeting »%s« with %s was updated." : "Fundurinn »%s« með %s var uppfærður.",
    "%s invited you to »%s«" : "%s bauð þér að taka þátt í »%s«",
    "When:" : "Hvenær:",
    "Where:" : "Hvar:",
    "Description:" : "Lýsing:",
    "Link:" : "Tengill:",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "More options at %s" : "Fleiri valkostir á %s",
    "Contacts" : "Tengiliðir",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tæknilegar upplýsingar",
    "Remote Address: %s" : "Fjartengt vistfang: %s",
    "Request ID: %s" : "Beiðni um auðkenni: %s",
    "There was an error updating your attendance status." : "Það kom upp villa við að uppfæra mætingarstöðu þína.",
    "Please contact the organizer directly." : "Hafðu samband beint við skipuleggjendurna.",
    "Are you accepting the invitation?" : "Ætlar þú að samþykkja boðið?",
    "Tentative" : "Bráðabirgða",
    "Save" : "Vista",
    "Your attendance was updated successfully." : "Mætingarstaða þín var uppfærð.",
    "Send invitations to attendees" : "Senda boð til þátttakenda",
    "Please make sure to properly set up the email settings above." : "Gakktu úr skugga um að tölvupóststillingarnar hér fyrir ofan séu réttar.",
    "Automatically generate a birthday calendar" : "Útbúa fæðingardagatal sjálfvirkt",
    "Birthday calendars will be generated by a background job." : "Fæðingardagatöl verða útbúin í bakvinnsluferli.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Þar með verða þau ekki tilbúin strax eftir að þetta er virkjað, heldur birtast þau eftir nokkurn tíma.",
    "CalDAV server" : "CalDAV-þjónn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/dav/l10n/is.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Dagatal",
    "Todos" : "Verkþættir",
    "Personal" : "Einka",
    "{actor} created calendar {calendar}" : "{actor} bjó til dagatalið {calendar}",
    "You created calendar {calendar}" : "Þú bjóst til dagatalið {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eyddi dagatalinu {calendar}",
    "You deleted calendar {calendar}" : "Þú eyddir dagatalinu {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppfærði dagatalið {calendar}",
    "You updated calendar {calendar}" : "Þú uppfærðir dagatalið {calendar}",
    "You shared calendar {calendar} as public link" : "Þú deildir dagatalinu {calendar} sem almenningstengli",
    "You removed public link for calendar {calendar}" : "Þú fjarlægðir almenningstengilinn fyrir dagatalið {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deildi dagatalinu {calendar} með þér",
    "You shared calendar {calendar} with {user}" : "Þú deildir dagatalinu {calendar} með {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deildi dagatalinu {calendar} með {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} tók af deilingu á dagatalinu {calendar} frá þér",
    "You unshared calendar {calendar} from {user}" : "Þú tókst af deilingu á dagatalinu {calendar} frá {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} tók af deilingu á dagatalinu {calendar} frá {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} tók af deilingu á dagatalinu {calendar} frá þeim sjálfum",
    "You shared calendar {calendar} with group {group}" : "Þú deildir dagatalinu {calendar} með hópnum {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deildi dagatalinu {calendar} með hópnum {group}",
    "You unshared calendar {calendar} from group {group}" : "Þú tókst af deilingu á dagatalinu {calendar} frá hópnum {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} tók af deilingu á dagatalinu {calendar} frá hópnum {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} bjó til atburðinn {event} í dagatalinu {calendar}",
    "You created event {event} in calendar {calendar}" : "Þú bjóst til atburðinn {event} í dagatalinu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eyddi atburðinum {event} úr dagatalinu {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Þú eyddir atburðinum {event} úr dagatalinu {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppfærði atburðinn {event} í dagatalinu {calendar}",
    "You updated event {event} in calendar {calendar}" : "Þú uppfærðir atburðinn {event} í dagatalinu {calendar}",
    "Busy" : "Upptekið",
    "{actor} created todo {todo} in list {calendar}" : "{actor} bjó til verkefnið {todo} á listanum {calendar}",
    "You created todo {todo} in list {calendar}" : "Þú bjóst til verkefnið {todo} á listanum {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eyddi verkefninu {todo} af listanum {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Þú eyddir verkefninu {todo} af listanum {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppfærði verkefnið {todo} á listanum {calendar}",
    "You updated todo {todo} in list {calendar}" : "Þú uppfærðir verkefnið {todo} á listanum {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} leysti verkefnið {todo} á listanum {calendar}",
    "You solved todo {todo} in list {calendar}" : "Þú leystir verkefnið {todo} á listanum {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} opnaði aftur verkefnið {todo} á listanum {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Þú opnaðir aftur verkefnið {todo} á listanum {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Dagatali</strong> var breytt",
    "A calendar <strong>event</strong> was modified" : "<strong>Atburði</strong> dagatals var breytt",
    "A calendar <strong>todo</strong> was modified" : "<strong>Verkefnalista</strong> dagatals var breytt",
    "Contact birthdays" : "Afmælisdagar tengiliðar",
    "Calendar:" : "Dagatal:",
    "Date:" : "Dagsetning:",
    "Where:" : "Hvar:",
    "Description:" : "Lýsing:",
    "Untitled event" : "Ónefndur atburður",
    "_%n year_::_%n years_" : ["%n ár","%n ár"],
    "_%n month_::_%n months_" : ["%n mánuður","%n mánuðir"],
    "_%n day_::_%n days_" : ["%n dagur","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n klukkustund","%n klukkustundir"],
    "_%n minute_::_%n minutes_" : ["%n mínúta","%n mínútur"],
    "%s (in %s)" : "%s (í %s)",
    "%s (%s ago)" : "%s (%s síðan)",
    "Calendar: %s" : "Dagatal: %s",
    "Date: %s" : "Dagsetning: %s",
    "Description: %s" : "Lýsing: %s",
    "Where: %s" : "Hvar: %s",
    "%1$s via %2$s" : "%1$s með %2$s",
    "Invitation canceled" : "Hætt við boð",
    "Hello %s," : "Halló %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Hætt var við fundinn »%1$s« með %2$s.",
    "Invitation updated" : "Boð uppfært",
    "The meeting »%1$s« with %2$s was updated." : "Fundurinn »%1$s« með %2$s var uppfærður.",
    "%1$s invited you to »%2$s«" : "%1$s bauð þér að taka þátt í »%2$s«",
    "When:" : "Hvenær:",
    "Link:" : "Tengill:",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "More options …" : "Fleiri valkostir ...",
    "More options at %s" : "Fleiri valkostir á %s",
    "Contacts" : "Tengiliðir",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s þarf að vera sett upp til að nota HTTPS til að CalDAV og CardDAV virki með iOS/macOS.",
    "Configures a CalDAV account" : "Setur upp CalDAV aðgang",
    "Configures a CardDAV account" : "Setur upp CardDAV aðgang",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-endapunktur",
    "There was an error updating your attendance status." : "Það kom upp villa við að uppfæra mætingarstöðu þína.",
    "Please contact the organizer directly." : "Hafðu samband beint við skipuleggjendurna.",
    "Are you accepting the invitation?" : "Ætlar þú að samþykkja boðið?",
    "Tentative" : "Bráðabirgða",
    "Save" : "Vista",
    "Your attendance was updated successfully." : "Mætingarstaða þín var uppfærð.",
    "Calendar server" : "Dagatalaþjónn",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Settu líka upp {calendarappstoreopen}Calendar-forritið{linkclose}, eða {calendardocopen}-tengdu tölvuna þína & farsíma fyrir samstillingu ↗{linkclose}.",
    "Send invitations to attendees" : "Senda boð til þátttakenda",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Gakktu úr skugga um að {emailopen}póstþjóninn{linkclose} sé rétt uppsettur.",
    "Automatically generate a birthday calendar" : "Útbúa fæðingardagatal sjálfvirkt",
    "Birthday calendars will be generated by a background job." : "Fæðingardagatöl verða útbúin í bakvinnsluferli.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Þar með verða þau ekki tilbúin strax eftir að þetta er virkjað, heldur birtast þau eftir nokkurn tíma.",
    "Technical details" : "Tæknilegar upplýsingar",
    "Remote Address: %s" : "Fjartengt vistfang: %s",
    "Request ID: %s" : "Beiðni um auðkenni: %s"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
